@@ -6,20 +6,15 @@ from django.core.urlresolvers import reverse
 class RichText (forms.Textarea):
   def render (self, name, value, attrs=None):
     ret = super(RichText, self).render(name, value, attrs=attrs)
-    ret += """
-    <script type="text/javascript">
-      CKEDITOR.replace( \'id_%s\', {customConfig : \'%sks/js/ckconfig.js\'});
-    </script>
-    """ % (
-      name,
-      settings.STATIC_URL
-    )
+    ret = ret.replace('<textarea ', '<textarea class="pizza_editor" ')
     
     return mark_safe(ret)
     
   class Media:
-    #css = {'all': ('ks/redactor/redactor.css', 'ks/redactor/admin.css')}
+    css = {'all': ('ks/css/pizza_editor.css',)}
+    
     js = (
       'ks/ckeditor/ckeditor.js',
+      'ks/js/pizza_editor.js',
     )
     
\ No newline at end of file
